@@ -1,11 +1,7 @@
-(*
- * lwt_react.ml
- * ------------
- * Copyright : (c) 2011, Jérémie Dimino <jeremie@dimino.org>
- * Licence   : BSD3
- *
- * This file is a part of lwt.
- *)
+(* This file is part of Lwt, released under the MIT license. See LICENSE.md for
+   details, or visit https://github.com/ocsigen/lwt/blob/master/LICENSE.md. *)
+
+
 
 open Lwt.Infix
 
@@ -24,7 +20,7 @@ module E = struct
   let with_finaliser f event =
     let r = ref () in
     Gc.finalise (finalise f) r;
-    map (fun x -> ignore r; x) event
+    map (fun x -> ignore (Sys.opaque_identity r); x) event
 
   let next ev =
     let waiter, wakener = Lwt.task () in
@@ -33,10 +29,10 @@ module E = struct
     waiter
 
   let limit f e =
-    (* Thread which prevent [e] to occur while it is sleeping *)
+    (* Thread which prevents [e] from occurring while it is sleeping *)
     let limiter = ref Lwt.return_unit in
 
-    (* The occurence that is delayed until the limiter returns. *)
+    (* The occurrence that is delayed until the limiter returns. *)
     let delayed = ref None in
 
     (* The resulting event. *)
@@ -45,23 +41,30 @@ module E = struct
     let iter =
       fmap
         (fun x ->
-           if Lwt.state !limiter = Lwt.Sleep then begin
+           if Lwt.is_sleeping !limiter then begin
              (* The limiter is sleeping, we queue the event for later
                 delivering. *)
              match !delayed with
-               | Some cell ->
-                   (* An occurence is alreayd queued, replace it. *)
-                   cell := x;
-                   None
-               | None ->
-                   let cell = ref x in
-                   delayed := Some cell;
-                   Lwt.on_success !limiter (fun () -> let x = !cell in delayed := None; push x);
-                   None
+             | Some cell ->
+               (* An occurrence is already queued, replace it. *)
+               cell := x;
+               None
+             | None ->
+               let cell = ref x in
+               delayed := Some cell;
+               Lwt.on_success !limiter (fun () ->
+                  if Lwt.is_sleeping !limiter then
+                    delayed := None
+                  else
+                    let x = !cell in
+                    delayed := None;
+                    limiter := f ();
+                    push x);
+               None
            end else begin
              (* Set the limiter for future events. *)
              limiter := f ();
-             (* Send the occurence now. *)
+             (* Send the occurrence now. *)
              push x;
              None
            end)
@@ -91,17 +94,18 @@ module E = struct
   let of_stream stream =
     let event, push = create () in
     let t =
-      Lwt.pause () >>= fun () -> Lwt_stream.iter (fun v -> push v) stream in
+      Lwt.pause () >>= fun () ->
+      Lwt_stream.iter (fun v -> try push v with exn -> !Lwt.async_exception_hook exn) stream in
     with_finaliser (cancel_thread t) event
 
   let delay thread =
     match Lwt.poll thread with
-      | Some e ->
-          e
-      | None ->
-          let event, send = create () in
-          Lwt.on_success thread (fun e -> send e; stop event);
-          switch never event
+    | Some e ->
+      e
+    | None ->
+      let event, send = create () in
+      Lwt.on_success thread (fun e -> send e; stop event);
+      switch never event
 
   let keeped = ref []
 
@@ -109,7 +113,7 @@ module E = struct
     keeped := map ignore e :: !keeped
 
   (* +---------------------------------------------------------------+
-     | Event transofrmations                                         |
+     | Event transformations                                         |
      +---------------------------------------------------------------+ *)
 
   let run_p e =
@@ -123,10 +127,10 @@ module E = struct
     let iter =
       fmap
         (fun t ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> t))
-            (fun v -> push v);
-          None) e
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> t))
+             (fun v -> push v);
+           None) e
     in
     select [iter; event]
 
@@ -141,10 +145,10 @@ module E = struct
     let iter =
       fmap
         (fun x ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> f x))
-            (fun v -> push v);
-          None) e
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> f x))
+             (fun v -> push v);
+           None) e
     in
     select [iter; event]
 
@@ -153,8 +157,8 @@ module E = struct
     let iter =
       fmap
         (fun (f, x) ->
-          Lwt.on_success (f x) (fun v -> push v);
-          None)
+           Lwt.on_success (f x) (fun v -> push v);
+           None)
         (app (map (fun f x -> (f, x)) ef) e)
     in
     select [iter; event]
@@ -165,10 +169,10 @@ module E = struct
     let iter =
       fmap
         (fun (f, x) ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> f x))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> f x))
+             (fun v -> push v);
+           None)
         (app (map (fun f x -> (f, x)) ef) e)
     in
     select [iter; event]
@@ -203,15 +207,15 @@ module E = struct
       fmap
         (fun x ->
            match !previous with
-             | None ->
-                 previous := Some x;
-                 None
-             | Some y ->
-                 previous := Some x;
-                 Lwt.on_success
-                   (Lwt_mutex.with_lock mutex (fun () -> f x y))
-                   (fun v -> push v);
-                 None)
+           | None ->
+             previous := Some x;
+             None
+           | Some y ->
+             previous := Some x;
+             Lwt.on_success
+               (Lwt_mutex.with_lock mutex (fun () -> f x y))
+               (fun v -> push v);
+             None)
         e
     in
     select [iter; event]
@@ -232,10 +236,10 @@ module E = struct
 
   let rec rev_fold f acc = function
     | [] ->
-        Lwt.return acc
+      Lwt.return acc
     | x :: l ->
-        rev_fold f acc l >>= fun acc ->
-        f acc x
+      rev_fold f acc l >>= fun acc ->
+      f acc x
 
   let merge_s f acc el =
     let event, push = create () in
@@ -243,10 +247,10 @@ module E = struct
     let iter =
       fmap
         (fun l ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> rev_fold f acc l))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> rev_fold f acc l))
+             (fun v -> push v);
+           None)
         (merge (fun acc x -> x :: acc) [] el)
     in
     select [iter; event]
@@ -264,13 +268,15 @@ module S = struct
   let with_finaliser f signal =
     let r = ref () in
     Gc.finalise (finalise f) r;
-    map (fun x -> ignore r; x) signal
+    map
+      (fun x -> ignore (Sys.opaque_identity r); x)
+      signal
 
   let limit ?eq f s =
     (* Thread which prevent [s] to changes while it is sleeping *)
     let limiter = ref (f ()) in
 
-    (* The occurence that is delayed until the limiter returns. *)
+    (* The occurrence that is delayed until the limiter returns. *)
     let delayed = ref None in
 
     (* The resulting event. *)
@@ -279,23 +285,30 @@ module S = struct
     let iter =
       E.fmap
         (fun x ->
-           if Lwt.state !limiter = Lwt.Sleep then begin
+           if Lwt.is_sleeping !limiter then begin
              (* The limiter is sleeping, we queue the event for later
                 delivering. *)
              match !delayed with
-               | Some cell ->
-                   (* An occurence is alreayd queued, replace it. *)
-                   cell := x;
-                   None
-               | None ->
-                   let cell = ref x in
-                   delayed := Some cell;
-                   Lwt.on_success !limiter (fun () -> let x = !cell in delayed := None; push x);
-                   None
+             | Some cell ->
+               (* An occurrence is already queued, replace it. *)
+               cell := x;
+               None
+             | None ->
+               let cell = ref x in
+               delayed := Some cell;
+               Lwt.on_success !limiter (fun () ->
+                if Lwt.is_sleeping !limiter then
+                  delayed := None
+                else
+                  let x = !cell in
+                  delayed := None;
+                  limiter := f ();
+                  push x);
+               None
            end else begin
              (* Set the limiter for future events. *)
              limiter := f ();
-             (* Send the occurence now. *)
+             (* Send the occurrence now. *)
              push x;
              None
            end)
@@ -310,7 +323,7 @@ module S = struct
     keeped := map ignore s :: !keeped
 
   (* +---------------------------------------------------------------+
-     | Signal transofrmations                                        |
+     | Signal transformations                                        |
      +---------------------------------------------------------------+ *)
 
   let run_s ?eq s =
@@ -319,10 +332,10 @@ module S = struct
     let iter =
       E.fmap
         (fun t ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> t))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> t))
+             (fun v -> push v);
+           None)
         (changes s)
     in
     Lwt_mutex.with_lock mutex (fun () -> value s) >>= fun x ->
@@ -334,9 +347,9 @@ module S = struct
     let iter =
       E.fmap
         (fun x ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> f x)) (fun v -> push v);
-            None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> f x)) (fun v -> push v);
+           None)
         (changes s)
     in
     Lwt_mutex.with_lock mutex (fun () -> f (value s)) >>= fun x ->
@@ -348,10 +361,10 @@ module S = struct
     let iter =
       E.fmap
         (fun (f, x) ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> f x))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> f x))
+             (fun v -> push v);
+           None)
         (E.app (E.map (fun f x -> (f, x)) (changes sf)) (changes s))
     in
     Lwt_mutex.with_lock mutex (fun () -> (value sf) (value s)) >>= fun x ->
@@ -363,20 +376,20 @@ module S = struct
     let iter = E.fmap (fun x -> Lwt.on_success (Lwt_mutex.with_lock mutex (fun () -> f x)) (function true -> push x | false -> ()); None) (changes s) in
     let x = value s in
     Lwt_mutex.with_lock mutex (fun () -> f x) >>= function
-      | true ->
-          Lwt.return (hold ?eq x (E.select [iter; event]))
-      | false ->
-          Lwt.return (hold ?eq i (E.select [iter; event]))
+    | true ->
+      Lwt.return (hold ?eq x (E.select [iter; event]))
+    | false ->
+      Lwt.return (hold ?eq i (E.select [iter; event]))
 
   let fmap_s ?eq f i s =
     let event, push = E.create () in
     let mutex = Lwt_mutex.create () in
     let iter = E.fmap (fun x -> Lwt.on_success (Lwt_mutex.with_lock mutex (fun () -> f x)) (function Some x -> push x | None -> ()); None) (changes s) in
     Lwt_mutex.with_lock mutex (fun () -> f (value s)) >>= function
-      | Some x ->
-          Lwt.return (hold ?eq x (E.select [iter; event]))
-      | None ->
-          Lwt.return (hold ?eq i (E.select [iter; event]))
+    | Some x ->
+      Lwt.return (hold ?eq x (E.select [iter; event]))
+    | None ->
+      Lwt.return (hold ?eq i (E.select [iter; event]))
 
   let diff_s f s =
     let previous = ref (value s) in
@@ -406,10 +419,10 @@ module S = struct
 
   let rec rev_fold f acc = function
     | [] ->
-        Lwt.return acc
+      Lwt.return acc
     | x :: l ->
-        rev_fold f acc l >>= fun acc ->
-        f acc x
+      rev_fold f acc l >>= fun acc ->
+      f acc x
 
   let merge_s ?eq f acc sl =
     let s = merge (fun acc x -> x :: acc) [] sl in
@@ -418,10 +431,10 @@ module S = struct
     let iter =
       E.fmap
         (fun l ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> rev_fold f acc l))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> rev_fold f acc l))
+             (fun v -> push v);
+           None)
         (changes s)
     in
     Lwt_mutex.with_lock mutex (fun () -> rev_fold f acc (value s)) >>= fun x ->
@@ -431,19 +444,21 @@ module S = struct
     map_s ?eq f s1
 
   let l2_s ?eq f s1 s2 =
-    map_s ?eq (fun (x1, x2) -> f x1 x2) (l2 (fun x1 x2 -> (x1, x2)) s1 s2)
+    (* Some details about the use of [fun _ _ -> false] on
+       https://github.com/ocsigen/lwt/pull/893#pullrequestreview-783083496 *)
+    map_s ?eq (fun (x1, x2) -> f x1 x2) (l2 ~eq:(fun _ _ -> false) (fun x1 x2 -> (x1, x2)) s1 s2)
 
   let l3_s ?eq f s1 s2 s3 =
-    map_s ?eq (fun (x1, x2, x3) -> f x1 x2 x3) (l3 (fun x1 x2 x3-> (x1, x2, x3)) s1 s2 s3)
+    map_s ?eq (fun (x1, x2, x3) -> f x1 x2 x3) (l3 ~eq:(fun _ _ -> false) (fun x1 x2 x3-> (x1, x2, x3)) s1 s2 s3)
 
   let l4_s ?eq f s1 s2 s3 s4 =
-    map_s ?eq (fun (x1, x2, x3, x4) -> f x1 x2 x3 x4) (l4 (fun x1 x2 x3 x4-> (x1, x2, x3, x4)) s1 s2 s3 s4)
+    map_s ?eq (fun (x1, x2, x3, x4) -> f x1 x2 x3 x4) (l4 ~eq:(fun _ _ -> false) (fun x1 x2 x3 x4-> (x1, x2, x3, x4)) s1 s2 s3 s4)
 
   let l5_s ?eq f s1 s2 s3 s4 s5 =
-    map_s ?eq (fun (x1, x2, x3, x4, x5) -> f x1 x2 x3 x4 x5) (l5 (fun x1 x2 x3 x4 x5-> (x1, x2, x3, x4, x5)) s1 s2 s3 s4 s5)
+    map_s ?eq (fun (x1, x2, x3, x4, x5) -> f x1 x2 x3 x4 x5) (l5 ~eq:(fun _ _ -> false) (fun x1 x2 x3 x4 x5-> (x1, x2, x3, x4, x5)) s1 s2 s3 s4 s5)
 
   let l6_s ?eq f s1 s2 s3 s4 s5 s6 =
-    map_s ?eq (fun (x1, x2, x3, x4, x5, x6) -> f x1 x2 x3 x4 x5 x6) (l6 (fun x1 x2 x3 x4 x5 x6-> (x1, x2, x3, x4, x5, x6)) s1 s2 s3 s4 s5 s6)
+    map_s ?eq (fun (x1, x2, x3, x4, x5, x6) -> f x1 x2 x3 x4 x5 x6) (l6 ~eq:(fun _ _ -> false) (fun x1 x2 x3 x4 x5 x6-> (x1, x2, x3, x4, x5, x6)) s1 s2 s3 s4 s5 s6)
 
   (* +---------------------------------------------------------------+
      | Monadic interface                                             |
@@ -458,10 +473,10 @@ module S = struct
     let iter =
       E.fmap
         (fun x ->
-          Lwt.on_success
-            (Lwt_mutex.with_lock mutex (fun () -> f x))
-            (fun v -> push v);
-          None)
+           Lwt.on_success
+             (Lwt_mutex.with_lock mutex (fun () -> f x))
+             (fun v -> push v);
+           None)
         (changes s)
     in
     Lwt_mutex.with_lock mutex (fun () -> f (value s)) >>= fun x ->
